@@ -7,6 +7,7 @@ from .product import *
 from .stock import *
 from .configuration import *
 from .invoice import *
+from .party import PartyReplace
 
 
 def register():
@@ -28,6 +29,8 @@ def register():
         HandleShipmentExceptionAsk,
         HandleInvoiceExceptionAsk,
         Configuration,
+        ConfigurationSequence,
+        ConfigurationPurchaseMethod,
         Invoice,
         InvoiceLine,
         Location,
@@ -39,5 +42,5 @@ def register():
         OpenSupplier,
         HandleShipmentException,
         HandleInvoiceException,
-        OpenProductQuantitiesByWarehouse,
+        PartyReplace,
         module='purchase', type_='wizard')
