@@ -170,8 +170,6 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
         cls._error_messages.update({
                 'warehouse_required': ('A warehouse must be defined for '
                     'quotation of purchase "%s".'),
-                'missing_account_payable': ('Missing "Account Payable" on '
-                    'party "%s".'),
                 'delete_cancel': ('Purchase "%s" must be cancelled before '
                     'deletion.'),
                 })
@@ -198,8 +196,12 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
                     },
                 'quote': {
                     'pre_validate': [
-                        ('purchase_date', '!=', None),
-                        ('invoice_address', '!=', None),
+                        If(~Eval('purchase_date'),
+                            ('purchase_date', '!=', None),
+                            ()),
+                        If(~Eval('invoice_address'),
+                            ('invoice_address', '!=', None),
+                            ()),
                         ],
                     'invisible': Eval('state') != 'draft',
                     'readonly': ~Eval('lines', []),
@@ -454,7 +456,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
 
     def get_tax_amount(self):
         taxes = self._get_taxes().itervalues()
-        return sum(tax['amount'] for tax in taxes)
+        return sum((tax['amount'] for tax in taxes), Decimal(0))
 
     @classmethod
     def get_amount(cls, purchases, names):
@@ -508,7 +510,8 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
 
     @classmethod
     def search_invoices(cls, name, clause):
-        return [('lines.invoice_lines.invoice',) + tuple(clause[1:])]
+        return [('lines.invoice_lines.invoice' + clause[0].lstrip(name),)
+            + tuple(clause[1:])]
 
     def get_invoice_state(self):
         '''
@@ -574,6 +577,19 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
                     'shipment_state': state,
                     })
 
+    @property
+    def report_address(self):
+        if self.invoice_address:
+            return self.invoice_address.full_address
+        else:
+            return ''
+
+    @property
+    def delivery_full_address(self):
+        if self.warehouse and self.warehouse.address:
+            return self.warehouse.address.full_address
+        return ''
+
     def get_rec_name(self, name):
         if self.number:
             return self.number
@@ -674,7 +690,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
             party=self.party,
             invoice_address=self.invoice_address,
             currency=self.currency,
-            account=self.party.account_payable,
+            account=self.party.account_payable_used,
             payment_term=self.payment_term,
             )
 
@@ -686,10 +702,6 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
         if self.invoice_method == 'manual':
             return
 
-        if not self.party.account_payable:
-            self.raise_user_error('missing_account_payable',
-                    error_args=(self.party.rec_name,))
-
         invoice_lines = []
         for line in self.lines:
             invoice_lines.append(line.get_invoice_line())
@@ -812,6 +824,13 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
     def handle_shipment_exception(cls, purchases):
         pass
 
+    @classmethod
+    def cron_process(cls):
+        purchases = cls.search([
+                ('state', '=', 'confirmed'),
+                ])
+        cls.process(purchases)
+
     @classmethod
     @ModelView.button
     def process(cls, purchases):
@@ -825,7 +844,10 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
                 purchase.create_return_shipment(return_moves)
             purchase.set_shipment_state()
             if purchase.is_done():
-                done.append(purchase)
+                if purchase.state != 'done':
+                    if purchase.state == 'confirmed':
+                        process.append(purchase)
+                    done.append(purchase)
             elif purchase.state != 'processing':
                 process.append(purchase)
         if process:
@@ -1092,7 +1114,7 @@ class PurchaseLine(sequence_ordered(), ModelSQL, ModelView):
         if self.unit:
             context['uom'] = self.unit.id
         else:
-            self.product.purchase_uom.id
+            context['uom'] = self.product.purchase_uom.id
         context['taxes'] = [t.id for t in self.taxes]
         return context
 
@@ -1225,7 +1247,8 @@ class PurchaseLine(sequence_ordered(), ModelSQL, ModelView):
     def on_change_with_delivery_date(self, name=None):
         if self.moves:
             dates = filter(
-                None, (m.effective_date or m.planned_date for m in self.moves))
+                None, (m.effective_date or m.planned_date for m in self.moves
+                    if m.state != 'cancel'))
             if dates:
                 return min(dates)
             else:
@@ -1395,7 +1418,11 @@ class PurchaseLine(sequence_ordered(), ModelSQL, ModelView):
         move.company = self.purchase.company
         move.unit_price = self.unit_price
         move.currency = self.purchase.currency
-        move.planned_date = self.delivery_date
+        if self.moves:
+            # backorder can not be planned
+            move.planned_date = None
+        else:
+            move.planned_date = self.delivery_date
         move.invoice_lines = self._get_move_invoice_lines(move_type)
         move.origin = self
         return move
