@@ -50,8 +50,9 @@ class PurchaseTestCase(ModuleTestCase):
                         'default_uom': g.id,
                         'purchase_uom': kg.id,
                         'list_price': Decimal(5),
-                        'cost_price': Decimal(2),
-                        'products': [('create', [{}])],
+                        'products': [('create', [{
+                                        'cost_price': Decimal(2),
+                                        }])],
                         }])
             product, = template.products
 
@@ -110,4 +111,8 @@ def suite():
             tearDown=doctest_teardown, encoding='UTF-8',
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE,
             checker=doctest_checker))
+    suite.addTests(doctest.DocFileSuite('scenario_purchase_empty.rst',
+            tearDown=doctest_teardown, encoding='UTF-8',
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE,
+            checker=doctest_checker))
     return suite
